==> react-atom-input-4.22.0.tgz: package/lib/Input/Features/Icon/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React from 'react';
import cx from 'classnames';
var TYPES = {
  LEFT: 'left',
  RIGHT: 'right'
};
var BASE_CLASS = 'sui-AtomInput';
var CLASS_ICON = BASE_CLASS + "--withIcon";
var CLASS_ICON_LEFT = CLASS_ICON + "--" + TYPES.LEFT;
var CLASS_ICON_RIGHT = CLASS_ICON + "--" + TYPES.RIGHT;
var CLASS_ICON_COMPONENT = CLASS_ICON + "-icon";
var CLASS_ICON_COMPONENT_HANDLER = CLASS_ICON_COMPONENT + "--withHandler";
var CLASS_ICON_COMPONENT_LEFT = CLASS_ICON_COMPONENT + "--" + TYPES.LEFT;
var CLASS_ICON_COMPONENT_RIGHT = CLASS_ICON_COMPONENT + "--" + TYPES.RIGHT;

var IconHoC = function IconHoC(WrappedInput) {
  var _temp;

  return _temp = /*#__PURE__*/function (_React$Component) {
    _inheritsLoose(Icon, _React$Component);

    function Icon() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

      _this.handleLeftClick = function (e) {
        var onClickLeftIcon = _this.props.onClickLeftIcon;
        onClickLeftIcon && onClickLeftIcon(e);
      };

      _this.handleRightClick = function (e) {
        var onClickRightIcon = _this.props.onClickRightIcon;
        onClickRightIcon && onClickRightIcon(e);
      };

      return _this;
    }

    var _proto = Icon.prototype;

    _proto.render = function render() {
      var _cx, _cx2, _cx3;

      var _this$props = this.props,
          leftIcon = _this$props.leftIcon,
          rightIcon = _this$props.rightIcon,
          onClickLeftIcon = _this$props.onClickLeftIcon,
          onClickRightIcon = _this$props.onClickRightIcon,
          props = _objectWithoutPropertiesLoose(_this$props, ["leftIcon", "rightIcon", "onClickLeftIcon", "onClickRightIcon"]);

      return leftIcon || rightIcon ? /*#__PURE__*/React.createElement("div", {
        className: cx(CLASS_ICON, (_cx = {}, _cx[CLASS_ICON_LEFT] = leftIcon, _cx[CLASS_ICON_RIGHT] = rightIcon, _cx))
      }, leftIcon && /*#__PURE__*/React.createElement("span", {
        className: cx(CLASS_ICON_COMPONENT, CLASS_ICON_COMPONENT_LEFT, (_cx2 = {}, _cx2[CLASS_ICON_COMPONENT_HANDLER] = onClickLeftIcon, _cx2)),
        onClick: this.handleLeftClick
      }, leftIcon), /*#__PURE__*/React.createElement(WrappedInput, props), rightIcon && /*#__PURE__*/React.createElement("span", {
        className: cx(CLASS_ICON_COMPONENT, CLASS_ICON_COMPONENT_RIGHT, (_cx3 = {}, _cx3[CLASS_ICON_COMPONENT_HANDLER] = onClickRightIcon, _cx3)),
        onClick: this.handleRightClick
      }, rightIcon)) : /*#__PURE__*/React.createElement(WrappedInput, props);
    };

    return Icon;
  }(React.Component), _temp;
};

export default IconHoC;

==> react-atom-input-5.0.0.tgz: package/lib/Input/Features/Icon/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import React from 'react';
import cx from 'classnames';
var TYPES = {
  LEFT: 'left',
  RIGHT: 'right'
};
var BASE_CLASS = 'sui-AtomInput';
var CLASS_ICON = BASE_CLASS + "--withIcon";
var CLASS_ICON_LEFT = CLASS_ICON + "--" + TYPES.LEFT;
var CLASS_ICON_RIGHT = CLASS_ICON + "--" + TYPES.RIGHT;
var CLASS_ICON_COMPONENT = CLASS_ICON + "-icon";
var CLASS_ICON_COMPONENT_HANDLER = CLASS_ICON_COMPONENT + "--withHandler";
var CLASS_ICON_COMPONENT_LEFT = CLASS_ICON_COMPONENT + "--" + TYPES.LEFT;
var CLASS_ICON_COMPONENT_RIGHT = CLASS_ICON_COMPONENT + "--" + TYPES.RIGHT;

var IconHoC = function IconHoC(WrappedInput) {
  var _temp;

  return _temp = /*#__PURE__*/function (_React$Component) {
    _inheritsLoose(Icon, _React$Component);

    function Icon() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

      _this.handleLeftClick = function (e) {
        var onClickLeftIcon = _this.props.onClickLeftIcon;
        onClickLeftIcon && onClickLeftIcon(e);
      };

      _this.handleRightClick = function (e) {
        var onClickRightIcon = _this.props.onClickRightIcon;
        onClickRightIcon && onClickRightIcon(e);
      };

      return _this;
    }

    var _proto = Icon.prototype;

    _proto.render = function render() {
      var _cx, _cx2, _cx3;

      var _this$props = this.props,
          leftIcon = _this$props.leftIcon,
          rightIcon = _this$props.rightIcon,
          onClickLeftIcon = _this$props.onClickLeftIcon,
          onClickRightIcon = _this$props.onClickRightIcon,
          props = _objectWithoutPropertiesLoose(_this$props, ["leftIcon", "rightIcon", "onClickLeftIcon", "onClickRightIcon"]);

      return leftIcon || rightIcon ? /*#__PURE__*/_jsxs("div", {
        className: cx(CLASS_ICON, (_cx = {}, _cx[CLASS_ICON_LEFT] = leftIcon, _cx[CLASS_ICON_RIGHT] = rightIcon, _cx)),
        children: [leftIcon && /*#__PURE__*/_jsx("span", {
          className: cx(CLASS_ICON_COMPONENT, CLASS_ICON_COMPONENT_LEFT, (_cx2 = {}, _cx2[CLASS_ICON_COMPONENT_HANDLER] = onClickLeftIcon, _cx2)),
          onClick: this.handleLeftClick,
          children: leftIcon
        }), /*#__PURE__*/_jsx(WrappedInput, _extends({}, props)), rightIcon && /*#__PURE__*/_jsx("span", {
          className: cx(CLASS_ICON_COMPONENT, CLASS_ICON_COMPONENT_RIGHT, (_cx3 = {}, _cx3[CLASS_ICON_COMPONENT_HANDLER] = onClickRightIcon, _cx3)),
          onClick: this.handleRightClick,
          children: rightIcon
        })]
      }) : /*#__PURE__*/_jsx(WrappedInput, _extends({}, props));
    };

    return Icon;
  }(React.Component), _temp;
};

export default IconHoC;
